@@ -1,4 +1,5 @@
 import os, os.path, gevent, pools, exchanges, coins, difficulty_sites, sys
+import gevent
 
 class Objects(object):
     def __init__(self):
@@ -22,18 +23,19 @@ class Objects(object):
         except:
             FD_DIR = os.curdir
         
+        for file_name in os.listdir(os.path.join(FD_DIR,'difficulty_sites')):
+            self.difficulty_sites.add(difficulty_sites.Site(
+                reduce(os.path.join, [FD_DIR, 'difficulty_sites', file_name]),
+                self,
+            ))
+        gevent.sleep(0)
+            
         #Parse config files and create objects
         for file_name in os.listdir(os.path.join(FD_DIR,'coins')):
             self.coins.add(coins.Coin(
                 reduce(os.path.join, [FD_DIR, 'coins', file_name, ]),
                 self,
             ))
-        
-        for file_name in os.listdir(os.path.join(FD_DIR,'difficulty_sites')):
-            self.difficulty_sites.add(difficulty_sites.Site(
-                reduce(os.path.join, [FD_DIR, 'difficulty_sites', file_name]),
-                self,
-            ))
             
         for file_name in os.listdir(os.path.join(FD_DIR,'exchanges')):
             self.exchanges.add(exchanges.Exchange(
